@@ -28,14 +28,14 @@ sub id {
   $self->{data}{id} //= $self->CHECKS->{id}{default};    #getting value
 }
 
-my $users_table = <<"T";
+my $users_table = <<"TAB";
 CREATE TABLE users(
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   group_id INT default 1,
   login_name VARCHAR(12),
   login_password VARCHAR(100)
   )
-T
+TAB
 
 my $dbh = __PACKAGE__->dbix->dbh;
 $dbh->do($users_table)
